@@ -10,7 +10,9 @@ use WebService::SSLLabs::Host();
 use WebService::SSLLabs::Endpoint();
 use WebService::SSLLabs::StatusCodes();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
+
+sub _MINIMUM_ETA_TIME { return 10; }
 
 sub new {
     my ($class) = @_;
@@ -62,6 +64,7 @@ sub analyze {
     if ( $response->is_success() ) {
         my $host = WebService::SSLLabs::Host->new(
             JSON::decode_json( $response->decoded_content() ) );
+        $self->{_previous_host} = $host;
         return $host;
     }
     else {
@@ -70,6 +73,21 @@ sub analyze {
     return;
 }
 
+sub previous_eta {
+    my ($self) = @_;
+    my $eta = _MINIMUM_ETA_TIME();
+    if ( $self->{_previous_host} ) {
+        my $host_eta = $self->{_previous_host}->eta();
+        if (   ( defined $host_eta )
+            && ( $host_eta =~ /^\d+$/smx )
+            && ( $host_eta >= $eta ) )
+        {
+            $eta = $host_eta;
+        }
+    }
+    return $eta;
+}
+
 sub _sort_ssllabs_params {
     if ( $a eq 'host' ) {
         return -1;
@@ -130,7 +148,7 @@ WebService::SSLLabs - Analyze the configuration of any SSL web server on the pub
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SYNOPSIS
 
@@ -141,7 +159,7 @@ Check the security of your TLS services
     my $labs = WebService::SSLLabs->new();
     my $host;
     while(not $host = $labs->analyze(host => 'ssllabs.com')->complete()) {
-        sleep 10;
+        sleep $labs->previous_eta();
     }
     if ($host->ready()) {
         foreach my $endpoint ($host->endpoints()) {
@@ -168,11 +186,11 @@ a new C<WebService::SSLLabs> object, ready to process TLS services
 
 =head2 info
 
-This call should be used to check the availability of the SSL Labs servers, retrieve the engine and criteria version, and initialize the maximum number of concurrent assessments. Returns one L<WebService::SSLLabs::Info|WebService::SSLLabs::Info> object on success.
+This call should be used to check the availability of the SSL Labs servers, retrieve the engine and criteria version, and initialize the maximum number of concurrent assessments. Returns one L<Info|WebService::SSLLabs::Info> object on success.
 
 =head2 analyze
 
-This call is used to initiate an assessment, or to retrieve the status of an assessment in progress or in the cache. It will return a single L<WebService::SSLLabs::Host|WebService::SSLLabs::Host> object on success. The L<WebService::SSLLabs::Endpoint|WebService::SSLLabs::Endpoint> object embedded in the L<WebService::SSLLabs::Host|WebService::SSLLabs::Host> object will provide partial endpoint results.
+This call is used to initiate an assessment, or to retrieve the status of an assessment in progress or in the cache. It will return a single L<Host|WebService::SSLLabs::Host> object on success. The L<Endpoint|WebService::SSLLabs::Endpoint> object embedded in the L<Host|WebService::SSLLabs::Host> object will provide partial endpoint results.
 
 Parameters:
 
@@ -188,15 +206,19 @@ Parameters:
 
 =item * max_age - maximum report age, in hours, if retrieving from cache (from_cache parameter set).
 
-=item * all - by default this call results only summaries of individual endpoints. If this parameter is set to "on", full information will be returned. If set to "done", full information will be returned only if the assessment is complete (L<status|WebService::SSLLabs::Host/"status"> is READY or ERROR).
+=item * all - by default this call results only summaries of individual endpoints. If this parameter is set to "on", full information will be returned. If set to "done", full information will be returned only if the assessment is L<complete|WebService::SSLabs::Host/"complete"> (L<status|WebService::SSLLabs::Host/"status"> is READY or ERROR).
 
 =item * ignore_mismatch - set to "on" to proceed with assessments even when the server certificate doesn't match the assessment host name. Set to "off" by default. Please note that this parameter is ignored if a cached report is returned.
 
 =back 
 
+=head2 previous_eta
+
+will return the highest of either 10 seconds or the L<eta|WebService::SSLLabs::Host/"eta"> values from the available L<endpoints|WebService::SSLLabs::Host/"endpoints"> from the previous L<analyze|WebService::SSLLabs/"analyze"> call.  This value is intended to act as the correct number of seconds to wait before calling L<analyze|WebService::SSLLabs/"analyze"> again
+
 =head2 get_endpoint_data
 
-This call is used to retrieve detailed endpoint information. It will return a single L<WebService::SSLLabs::Endpoint|WebService::SSLLabs::Endpoint> object on success. The object will contain complete assessment information. This call does not initiate new assessments, even when a cached report is not found.
+This call is used to retrieve detailed endpoint information. It will return a single L<Endpoint|WebService::SSLLabs::Endpoint> object on success. The object will contain complete assessment information. This call does not initiate new assessments, even when a cached report is not found.
 
 Parameters:
 
@@ -212,7 +234,7 @@ Parameters:
 
 =head2 get_status_codes
 
-This call will return one L<WebService::SSLLabs::StatusCodes|WebService::SSLLabs::StatusCodes> instance.
+This call will return one L<StatusCodes|WebService::SSLLabs::StatusCodes> instance.
 
 =head1 DIAGNOSTICS
 
