@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::ChainCert();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -43,7 +43,7 @@ WebService::SSLLabs::Chain - Chain object
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SUBROUTINES/METHODS
 
@@ -53,7 +53,7 @@ a new C<WebService::SSLLabs::Chain> object, accepts a hash ref as it's parameter
 
 =head2 certs
 
-a list of L<WebService::SSLLabs::ChainCert|WebService::SSLLabs::ChainCert> objects, representing the chain certificates in the order in which they were retrieved from the server
+a list of L<ChainCert|WebService::SSLLabs::ChainCert> objects, representing the chain certificates in the order in which they were retrieved from the server
 
 =head2 issues
 
