@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::EndpointDetails();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -98,7 +98,7 @@ WebService::SSLLabs::Endpoint - Endpoint object
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SUBROUTINES/METHODS
 
@@ -176,7 +176,7 @@ indicates domain name delegation with and without the www prefix
 
 =head2 details
 
-this field contains an L<WebService::SSLLabs::EndpointDetails|WebService::SSLLabs::EndpointDetails> object. It's not present by default, but can be enabled by using the "all" paramerer to the L<analyze|WebService::SSLLabs/"analyze"> API call.
+this field contains an L<EndpointDetails|WebService::SSLLabs::EndpointDetails> object. It's not present by default, but can be enabled by using the "all" paramerer to the L<analyze|WebService::SSLLabs/"analyze"> API call.
 
 =head1 DIAGNOSTICS
 
