@@ -9,7 +9,7 @@ use WebService::SSLLabs::Protocol();
 use WebService::SSLLabs::Chain();
 use WebService::SSLLabs::Key();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -250,7 +250,7 @@ WebService::SSLLabs::EndpointDetails - EndpointDetails object
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SUBROUTINES/METHODS
 
@@ -264,23 +264,23 @@ endpoint assessment starting time, in milliseconds since 1970. This field is use
 
 =head2 key
 
-returns the connected L<WebService::SSLLabs::Key|WebService::SSLLabs::Key> object
+returns the connected L<Key|WebService::SSLLabs::Key> object
 
 =head2 cert
 
-returns the connected L<WebService::SSLLabs::Cert|WebService::SSLLabs::Cert> object
+returns the connected L<Cert|WebService::SSLLabs::Cert> object
 
 =head2 chain
 
-returns the connected L<WebService::SSLLabs::Chain|WebService::SSLLabs::Chain> object
+returns the connected L<Chain|WebService::SSLLabs::Chain> object
 
 =head2 protocols
 
-returns the list of supported protocols as L<WebService::SSLLabs::Protocol|WebService::SSLLabs::Protocol> objects
+returns the list of supported protocols as L<Protocol|WebService::SSLLabs::Protocol> objects
 
 =head2 suites
 
-returns the L<WebService::SSLLabs::Suites|WebService::SSLLabs::Suites> object
+returns the L<Suites|WebService::SSLLabs::Suites> object
 
 =head2 server_signature
 
@@ -432,7 +432,7 @@ true if RC4 is used with modern clients.
 
 =head2 sims
 
-instance of L<WebService::SSLLabs::SimDetails|WebService::SSLLabs::SimDetails>.
+instance of L<SimDetails|WebService::SSLLabs::SimDetails>.
 
 =head2 heartbleed
 
