@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::Endpoint();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -44,6 +44,24 @@ sub complete {
     }
 }
 
+sub eta {
+    my ($self) = @_;
+    my $host_eta;
+    foreach my $endpoint ( $self->endpoints() ) {
+        if (   ( defined $endpoint->eta() )
+            && ( $endpoint->eta() =~ /^\d+$/smx ) )
+        {
+            if ( !defined $host_eta ) {
+                $host_eta = $endpoint->eta();
+            }
+            if ( $endpoint->eta() >= $host_eta ) {
+                $host_eta = $endpoint->eta();
+            }
+        }
+    }
+    return $host_eta;
+}
+
 sub status {
     my ($self) = @_;
     return $self->{status};
@@ -108,7 +126,7 @@ WebService::SSLLabs::Host - Host object
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SUBROUTINES/METHODS
 
@@ -125,6 +143,10 @@ assessment status; possible values: DNS, ERROR, IN_PROGRESS, and READY.
 
 will return the current C<WebService::SSLLabs::Host> object if L<status|WebService::SSLLabs::Host/"status"> is equal to READY.  Otherwise it will return undef.
 
+=head2 eta
+
+will return the highest of any of the L<eta|WebService::SSLLabs::Endpoint/"eta"> values from the available L<endpoints|WebService::SSLLabs::Host/"endpoints">.
+
 =head2 host 
 
 assessment host, which can be a hostname or an IP address
@@ -159,7 +181,7 @@ assessment completion time, in milliseconds since 1970
 
 =head2 engine_version
 
-assessment engine version (e.g., "1.0.150")
+assessment engine version (e.g., "1.0.160")
 
 =head2 criteria_version
 
@@ -171,7 +193,7 @@ when will the assessment results expire from the cache (typically set only for a
 
 =head2 endpoints
 
-list of L<WebService::SSLLabs::Endpoint|WebService::SSLLabs::Endpoint> objects
+list of L<Endpoint|WebService::SSLLabs::Endpoint> objects
 
 =head2 cert_hostnames
 
