@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::Simulation();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -33,7 +33,7 @@ WebService::SSLLabs::SimDetails - SimDetails object
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SUBROUTINES/METHODS
 
@@ -43,7 +43,7 @@ a new C<WebService::SSLLabs::SimDetails> object, accepts a hash ref as it's para
 
 =head2 results
 
-list of instances of L<WebService::SSLLabs::Simulation|WebService::SSLLabs::Simulation>.
+list of instances of L<Simulation|WebService::SSLLabs::Simulation>.
 
 =head1 DIAGNOSTICS
 
