@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::SimClient();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -48,7 +48,7 @@ WebService::SSLLabs::Simulation - Simulation object
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SUBROUTINES/METHODS
 
@@ -58,7 +58,7 @@ a new C<WebService::SSLLabs::Simulation> object, accepts a hash ref as it's para
 
 =head2 client
 
-instance of L<WebService::SSLLabs::SimClient|WebService::SSLLabs::SimClient>.
+instance of L<SimClient|WebService::SSLLabs::SimClient>.
 
 =head2 error_code
 
