@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::Suite();
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -42,7 +42,7 @@ WebService::SSLLabs::Suites - Suites object
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =head1 SUBROUTINES/METHODS
 
@@ -52,7 +52,7 @@ a new C<WebService::SSLLabs::Suites> object, accepts a hash ref as it's paramete
 
 =head2 list
 
-list of L<WebService::SSLLabs::Suite|WebService::SSLLabs::Suite> objects
+list of L<Suite|WebService::SSLLabs::Suite> objects
 
 =head2 preference
 
